#!/bin/bash
#
# Recipe-specific step for task Install: task.install.u-boot-stm32mp1-dhsom_2021.01-r0 (make_install.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

bbwarn() {
	if [ -p ${workDir}/temp/fifo.28091 ] ; then
		printf "%b\0" "bbwarn $*" > ${workDir}/temp/fifo.28091
	else
		echo "WARNING: $*"
	fi
}

install_helper() {
	if [ -f "u-boot.dtb" ]; then
		log_run install -d ${installDir}${datadir}
		# UBOOT_DTB_BINARY is a symlink to UBOOT_DTB_IMAGE, so we
		# need both of them.
		log_run install u-boot.dtb ${installDir}${datadir}/u-boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.dtb
		log_run ln -sf u-boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.dtb ${installDir}${datadir}/u-boot.dtb
	else
		bbwarn "u-boot.dtb not found"
	fi
}


function local_do_make_install() {
    if [ -n "$UBOOT_CONFIG" ]
    then
	for config in stm32mp15_dhcor_basic_defconfig; do
	    i=$(expr $i + 1);
	    for type in $UBOOT_CONFIG; do
		j=$(expr $j + 1);
		if [ $j -eq $i ]
		then
		    log_run install -D -m 644 ${buildDir}/$config/u-boot-$type.itb ${installDir}/boot/u-boot-$type-2021.01-r0.itb
		    log_run ln -sf u-boot-$type-2021.01-r0.itb ${installDir}/boot/u-boot.itb-$type
		    log_run ln -sf u-boot-$type-2021.01-r0.itb ${installDir}/boot/u-boot.itb

		    # Install the uboot-initial-env
		    if [ -n "u-boot-stm32mp1-dhsom-initial-env" ]; then
			log_run install -D -m 644 ${buildDir}/$config/u-boot-initial-env-$type ${installDir}/${sysconfdir}/u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-$type-2021.01-r0
			log_run ln -sf u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-$type-2021.01-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-$type
			log_run ln -sf u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-$type-2021.01-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp1-dhsom-initial-env-$type
			log_run ln -sf u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-$type-2021.01-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp1-dhsom-initial-env
		    fi
		fi
	    done
	    unset j
	done
	unset i
    else
	log_run install -D -m 644 ${buildDir}/u-boot.itb ${installDir}/boot/u-boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.itb
	log_run ln -sf u-boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.itb ${installDir}/boot/u-boot.itb

	# Install the uboot-initial-env
	if [ -n "u-boot-stm32mp1-dhsom-initial-env" ]; then
	    log_run install -D -m 644 ${buildDir}/u-boot-initial-env ${installDir}/${sysconfdir}/u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-2021.01-r0
	    log_run ln -sf u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-2021.01-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96
	    log_run ln -sf u-boot-stm32mp1-dhsom-initial-env-dh-stm32mp1-dhcor-avenger96-2021.01-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp1-dhsom-initial-env
	fi
    fi

    if [ -n "" ]
    then
	if [ -n "$UBOOT_CONFIG" ]
	then
	    for config in stm32mp15_dhcor_basic_defconfig; do
		i=$(expr $i + 1);
		for type in $UBOOT_CONFIG; do
		    j=$(expr $j + 1);
		    if [ $j -eq $i ]
		    then
			log_run install -m 644 ${buildDir}/$config ${installDir}/boot/u-boot-$type-2021.01-r0.elf
			log_run ln -sf u-boot-$type-2021.01-r0.elf ${installDir}/boot/u-boot.itb-$type
			log_run ln -sf u-boot-$type-2021.01-r0.elf ${installDir}/boot/u-boot.itb
		    fi
		done
		unset j
	    done
	    unset i
	else
	    log_run install -m 644 ${buildDir} ${installDir}/boot/u-boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.elf
	    log_run ln -sf u-boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.elf ${installDir}/boot/u-boot.elf
	fi
    fi

    if [ -e ${workDir}/fw_env.config ] ; then
	log_run install -d ${installDir}${sysconfdir}
	log_run install -m 644 ${workDir}/fw_env.config ${installDir}${sysconfdir}/fw_env.config
    fi

    if [ -n "u-boot-spl.stm32" ]
    then
	if [ -n "$UBOOT_CONFIG" ]
	then
	    for config in stm32mp15_dhcor_basic_defconfig; do
		i=$(expr $i + 1);
		for type in $UBOOT_CONFIG; do
		    j=$(expr $j + 1);
		    if [ $j -eq $i ]
		    then
			 log_run install -m 644 ${buildDir}/$config/u-boot-spl.stm32 ${installDir}/boot/u-boot-spl.stm32-dh-stm32mp1-dhcor-avenger96-2021.01-r0-$type-2021.01-r0
			 log_run ln -sf u-boot-spl.stm32-dh-stm32mp1-dhcor-avenger96-2021.01-r0-$type-2021.01-r0 ${installDir}/boot/u-boot-spl.stm32-$type
			 log_run ln -sf u-boot-spl.stm32-dh-stm32mp1-dhcor-avenger96-2021.01-r0-$type-2021.01-r0 ${installDir}/boot/u-boot-spl.stm32
		    fi
		done
		unset j
	    done
	    unset i
	else
	    log_run install -m 644 ${buildDir}/u-boot-spl.stm32 ${installDir}/boot/u-boot-spl.stm32-dh-stm32mp1-dhcor-avenger96-2021.01-r0
	    log_run ln -sf u-boot-spl.stm32-dh-stm32mp1-dhcor-avenger96-2021.01-r0 ${installDir}/boot/u-boot-spl.stm32
	fi
    fi

    if [ -n "boot" ]
    then
	log_run install -m 644 ${workDir}/boot.scr ${installDir}/boot/boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.scr
	log_run ln -sf boot-dh-stm32mp1-dhcor-avenger96-2021.01-r0.scr ${installDir}/boot/boot.scr
    fi

    if [ "$UBOOT_EXTLINUX" = "1" ]
    then
	log_run install -Dm 0644 ${buildDir}/extlinux.conf ${installDir}//boot/extlinux/extlinux.conf
    fi
	if [ "0" = "1" -a "${recipe_name}" = "${recipe_name}" -a -n "u-boot.dtb" ]; then
		if [ -n "$UBOOT_CONFIG" ]; then
			for config in stm32mp15_dhcor_basic_defconfig; do
				cd ${buildDir}/$config
				install_helper
			done
		else
			cd ${buildDir}
			install_helper
		fi
	fi
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append

