#!/bin/bash
# Generic buildstep script

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

generate_cmake_toolchain_file() {
	local cmake_crosscompiling cflags cxxflags
	if $recipe_is_native; then
		cmake_crosscompiling="set( CMAKE_CROSSCOMPILING FALSE )"
		cflags="$BUILD_CFLAGS"
		cxxflags="$BUILD_CXXFLAGS"
	else
		cflags="$TARGET_CFLAGS"
		cxxflags="$TARGET_CXXFLAGS"
	fi
	local arch="$arch_name"
	if [ "$arch" = "powerpc" ]; then arch="ppc"
	elif [ "$arch" = "powerpc64" ]; then arch="ppc64"
	fi
	: ${cmake_cxxflags:=$cmake_cflags}
	: ${cmake_cxx_ldflags:=$cmake_c_ldflags}
	: ${cmake_cxxflags_release:=$cmake_cflags_release}
	if $recipe_is_native; then
		local include_mode="BOTH"
		local library_mode="BOTH"
		local package_mode="BOTH"
		local program_mode="BOTH"
	else
		local include_mode="ONLY"
		local library_mode="ONLY"
		local package_mode="ONLY"
		local program_mode="ONLY"
	fi
	
	cat > $workDir/toolchain.cmake <<EOF
# CMake system name must be something like "Linux".
# This is important for cross-compiling.
$cmake_crosscompiling
set( CMAKE_SYSTEM_NAME Linux )
set( CMAKE_SYSTEM_PROCESSOR $arch )
set( CMAKE_C_COMPILER ${CROSS_COMPILER_PATH}/${CC} )
set( CMAKE_CXX_COMPILER ${CROSS_COMPILER_PATH}/${CXX} )
set( CMAKE_ASM_COMPILER ${CROSS_COMPILER_PATH}/${CC} )
set( CMAKE_AR ${AR} CACHE FILEPATH "Archiver" )
set( CMAKE_C_FLAGS "$cmake_cflags" CACHE STRING "CFLAGS" )
set( CMAKE_CXX_FLAGS "$cmake_cxxflags" CACHE STRING "CXXFLAGS" )
set( CMAKE_ASM_FLAGS "$cmake_cflags" CACHE STRING "ASM FLAGS" )
set( CMAKE_C_FLAGS_RELEASE "$cmake_cflags_release" CACHE STRING "Additional CFLAGS for release" )
set( CMAKE_CXX_FLAGS_RELEASE "$cmake_cxxflags_release" CACHE STRING "Additional CXXFLAGS for release" )
set( CMAKE_ASM_FLAGS_RELEASE "$cmake_cflags_release" CACHE STRING "Additional ASM FLAGS for release" )
set( CMAKE_C_LINK_FLAGS "$cmake_c_ldflags" CACHE STRING "LDFLAGS" )
set( CMAKE_CXX_LINK_FLAGS "$cmake_cxx_ldflags" CACHE STRING "LDFLAGS" )

# SYSROOT is not used, nor needed, by SW4L toolchains
# set( CMAKE_SYSROOT "$SYSROOT_LOC" CACHE STRING "SYSROOT" )

# However we must provide CMAKE_FIND_ROOT_PATH and select ONLY for CMAKE_FIND_ROOT_PATH_MODE_INCLUDE
# and CMAKE_FIND_ROOT_PATH_MODE_LIBRARY (let CMAKE_FIND_ROOT_PATH_MODE_PACKAGE to BOTH for now)
# As we patched cmake to support  CMAKE_FIND_HOST_ROOT_PATH, we are able to also set
# CMAKE_FIND_ROOT_PATH_MODE_PROGRAM to NEVER to only search for native programs
set( CMAKE_FIND_HOST_ROOT_PATH $NATIVE_SYSROOT_LOC $cmake_perlnative_dir $WEAK_SYSROOT_LOC )
set( CMAKE_FIND_ROOT_PATH $SYSROOT_LOC )
set( CMAKE_FIND_ROOT_PATH_MODE_PACKAGE $package_mode )
set( CMAKE_FIND_ROOT_PATH_MODE_PROGRAM $program_mode )
set( CMAKE_FIND_ROOT_PATH_MODE_LIBRARY $library_mode )
set( CMAKE_FIND_ROOT_PATH_MODE_INCLUDE $include_mode )

# We need to set the rpath to the correct directory as cmake does not provide any
# directory as rpath by default
set( CMAKE_INSTALL_RPATH $cmake_rpath )

# add for non /usr/lib libdir, e.g. /usr/lib64
set( CMAKE_LIBRARY_PATH ${libdir} ${base_libdir})
EOF

	if [ -r $workDir/qt.conf ]; then
		cat >> $workDir/toolchain.cmake <<EOF

# Use qt.conf settings
set( ENV{QT_CONF_PATH} $workDir/qt.conf )
EOF
	fi
	
	cat >> $workDir/toolchain.cmake <<EOF

# Use native cmake modules, if any
EOF
	if [ -d "${SYSROOT_LOC}${datadir}/cmake/Modules/" ]; then
		cat >> $workDir/toolchain.cmake <<EOF
list(APPEND CMAKE_MODULE_PATH "${SYSROOT_LOC}${datadir}/cmake/Modules/")
EOF
	fi
	if [ -d "${NATIVE_SYSROOT_LOC}${datadir}/cmake/Modules/" ]; then
		cat >> $workDir/toolchain.cmake <<EOF
list(APPEND CMAKE_MODULE_PATH "${NATIVE_SYSROOT_LOC}${datadir}/cmake/Modules/")
EOF
	fi
	if [ -d "${WEAK_SYSROOT_LOC}${datadir}/cmake/Modules/" ]; then
		cat >> $workDir/toolchain.cmake <<EOF
list(APPEND CMAKE_MODULE_PATH "${WEAK_SYSROOT_LOC}${datadir}/cmake/Modules/")
EOF
	fi
}

do_buildstep_prepend

do_buildstep

do_buildstep_append