#!/bin/bash
#
# Recipe-specific step for task Compile: task.compile.u-boot-stm32mp_v2021.10-stm32mp-r2-r0 (make_all.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

require_script "stm32mp_common_utils.sh"

function local_do_make_all() {
    if [ "" ]; then
		sed -i 's/$(CROSS_COMPILE)ld$/$(CROSS_COMPILE)ld.bfd/g' ${srcDir}/config.mk
    fi

    unset LDFLAGS
    unset CFLAGS
    unset CPPFLAGS

    if [ ! -e ${buildDir}/.scmversion -a ! -e ${srcDir}/.scmversion ]
    then
		echo  > ${buildDir}/.scmversion
		echo  > ${srcDir}/.scmversion
    fi

    if [ -n " ${UBOOT_CONFIG} " -o -n "$UBOOT_DELTA_CONFIG" ]
    then
		unset i j k
		for config in  ${UBOOT_MACHINE}; do
		    i=$(expr $i + 1);
		    for type in  ${UBOOT_CONFIG} ; do
			j=$(expr $j + 1);
			if [ $j -eq $i ]
			then
			    do_make -C ${srcDir} O=${buildDir}/$config all
			    for binary in  u-boot.dtb; do
				k=$(expr $k + 1);
				if [ $k -eq $i ]; then
				    log_run cp ${buildDir}/$config/$binary ${buildDir}/$config/u-boot-$type.bin
				fi
			    done
	
			    # Generate the uboot-initial-env
			    if [ -n "u-boot-stm32mp-initial-env" ]; then
				do_make -C ${srcDir} O=${buildDir}/$config u-boot-initial-env
				log_run cp ${buildDir}/$config/u-boot-initial-env ${buildDir}/$config/u-boot-initial-env-$type
			    fi
	
			    unset k
			fi
		    done
		    unset j
		done
		unset i
    else
		do_make -C ${srcDir} O=${buildDir} all
	
		# Generate the uboot-initial-env
		if [ -n "u-boot-stm32mp-initial-env" ]; then
		    do_make -C ${srcDir} O=${buildDir} u-boot-initial-env
		fi
    fi

    if [ -n "${UBOOT_ENV}" ] && [ "txt" = "scr" ]
    then
		uboot-mkimage -C none -A arm -T script -d ${workDir}/.cmd ${workDir}/.txt
    fi
    if [ -n " ${UBOOT_DEVICETREE} " ]; then
		if [ -n " ${UBOOT_CONFIG} " ]; then
		    unset i j k
		    for config in  ${UBOOT_MACHINE}; do
			i=$(expr $i + 1);
			for type in  ${UBOOT_CONFIG} ; do
			    j=$(expr $j + 1);
			    if [ $j -eq $i ]; then
				# Get short suffix for current type
				type_suffix=$(echo $type | cut -d'_' -f1)
				type_filter=$(echo $type | cut -d'_' -f2)
				[ "$type_suffix" = "$type_filter" ] && type_filter=""

			    if [ -n "$type_filter" ]; then
				if [ "$(echo $devicetree | grep -c $type_filter)" -eq 1 ]; then
				    message "The $type_filter filter for $type_suffix config matches $devicetree device tree. Go for build..."
				else
				    message "The $type_filter filter for $type_suffix config doesn't match $devicetree device tree. Skip build!"
				    continue
				fi
			    fi
			    # Cleanup previous build artifact
			    [ -f "${buildDir}/$config/dts/dt.dtb" ] && rm "${buildDir}/$config/dts/dt.dtb"
			    # Build target
			    do_make -C ${srcDir} O=${buildDir}/$config DEVICE_TREE=$devicetree DEVICE_TREE_EXT=$devicetree.dtb
			    # Install specific binary
			    for binary in  u-boot.dtb; do
				k=$(expr $k + 1);
				if [ $k -eq $i ]; then
				    binarysuffix=$(echo $binary | cut -d'.' -f2)
				    log_run install -m 644 ${buildDir}/$config/$binary ${buildDir}/$config/u-boot-$devicetree.$binarysuffix
				fi
			    done
			    unset k
			    # As soon as SPL binary exists, copy it with specific binary_type name
			    # This allow to mix u-boot configuration, with and without SPL
			    if [ -f "${buildDir}/$config/spl/u-boot-spl.stm32" ]; then
				log_run install -m 644 ${buildDir}/$config/spl/u-boot-spl.stm32 ${buildDir}/$config/u-boot-spl.stm32-$devicetree
			    fi

			    fi
			done
			unset j
		    done
		else
		    fatal_no_status "Wrong ${recipe_name} configuration: please make sure to use UBOOT_CONFIG through BOOTSCHEME_LABELS config"
		fi
    fi
}

do_buildstep_prepend

local_do_make_all

do_buildstep_append

