#!/bin/bash
#
# Recipe-specific step for task Install: task.install.optee-os-stm32mp_3.16.0-stm32mp-r2-r0 (make_install.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

# Configure optee binaries
OPTEE_HEADER="tee-header_v2"
OPTEE_PAGEABLE="tee-pageable_v2"
OPTEE_PAGER="tee-pager_v2"
OPTEE_SUFFIX="bin"
# Output the ELF generated
: ${ELF_DEBUG_ENABLE:=""}
OPTEE_ELF="tee"
OPTEE_ELF_SUFFIX="elf"

function local_do_make_install() {
    #install TA devkit
    log_run install -d ${installDir}${includedir}/optee/export-user_ta

    if [ -n " ${optee_conf} " ]; then
	for conf in  ${optee_conf} ; do
	    for f in  ${buildDir}/$conf/export-ta_arm32/* ; do
		log_run cp -aRf  $f ${installDir}${includedir}/optee/export-user_ta
	    done
	done
    fi

	local DEPLOYDIR=${D}/boot
	install -d ${DEPLOYDIR}
    if [ -n "${optee_conf}" ]; then
        for conf in ${optee_conf}; do
            install -m 644 ${B}/${conf}/core/${OPTEE_HEADER}.${OPTEE_SUFFIX} ${DEPLOYDIR}/${OPTEE_HEADER}-${conf}.${OPTEE_SUFFIX}
            install -m 644 ${B}/${conf}/core/${OPTEE_PAGER}.${OPTEE_SUFFIX} ${DEPLOYDIR}/${OPTEE_PAGER}-${conf}.${OPTEE_SUFFIX}
            install -m 644 ${B}/${conf}/core/${OPTEE_PAGEABLE}.${OPTEE_SUFFIX} ${DEPLOYDIR}/${OPTEE_PAGEABLE}-${conf}.${OPTEE_SUFFIX}
            if [ -n "${ELF_DEBUG_ENABLE}" ]; then
                install -m 644 ${B}/${conf}/core/${OPTEE_ELF}.${OPTEE_ELF_SUFFIX} ${DEPLOYDIR}/debug/${OPTEE_ELF}-${conf}.${OPTEE_ELF_SUFFIX}
            fi
        done
    else
        install -m 644 ${B}/core/${OPTEE_HEADER}.${OPTEE_SUFFIX}  ${DEPLOYDIR}/${OPTEE_HEADER}.${OPTEE_SUFFIX}
        install -m 644 ${B}/core/${OPTEE_PAGER}.${OPTEE_SUFFIX}  ${DEPLOYDIR}/${OPTEE_PAGER}.${OPTEE_SUFFIX}
        install -m 644 ${B}/core/${OPTEE_PAGEABLE}.${OPTEE_SUFFIX}  ${DEPLOYDIR}/${OPTEE_PAGEABLE}.${OPTEE_SUFFIX}
        if [ -n "${ELF_DEBUG_ENABLE}" ]; then
            install -m 644 ${B}/core/${OPTEE_ELF}.${OPTEE_ELF_SUFFIX} ${DEPLOYDIR}/debug/${OPTEE_ELF}.${OPTEE_ELF_SUFFIX}
        fi
    fi
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append

