#!/bin/bash
#
# Recipe-specific step for task Compile: task.compile.tf-a-stm32mp_v2.6-stm32mp-r2-r0 (make_all.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

require_script "stm32mp_common_utils.sh"

function local_do_make_all() {
    unset LDFLAGS
    unset CFLAGS
    unset CPPFLAGS
	
    unset i
    for config in ${TF_A_CONFIG} ; do
		i=$(expr $i + 1)
		# Initialize devicetree list, extra make options and tf-a basename
		dt_config=$(echo ${TF_A_DEVICETREE} | cut -d',' -f$i)
		extra_opt=$(echo ${TF_A_EXTRA_OPTFLAGS} | cut -d',' -f$i)
		tfa_basename=$(echo ${TF_A_BINARIES} | cut -d',' -f$i)
		tf_a_make_target=$(echo ${TF_A_MAKE_TARGET} | cut -d',' -f$i)
		for dt in $dt_config; do
		    # Init specific soc settings
		    soc_extra_opt=""
		    soc_suffix=""
		    if [ -n " ${stm32mp_soc_name} " ]; then
				for soc in  ${stm32mp_soc_name} ; do
				    if [ "$(echo $dt | grep -c $soc)" -eq 1 ]; then
					soc_extra_opt="$(echo $soc | awk '{print toupper($0)}')=1"
					soc_suffix="-$soc"
				    fi
				done
		    fi
		    log_run mkdir -p ${buildDir}/$config$soc_suffix
		    do_make -C "${srcDir}" BUILD_PLAT="${buildDir}/$config$soc_suffix" DTB_FILE_NAME="$dt.dtb" $extra_opt $soc_extra_opt $tf_a_make_target
		    # Copy TF-A binary with explicit devicetree filename
		    if [ -f "${buildDir}/$config$soc_suffix/$tfa_basename-$dt.stm32" ]; then
				log_run cp "${buildDir}/$config$soc_suffix/$tfa_basename-$dt.stm32" "${buildDir}/$config$soc_suffix/$tfa_basename-$dt-$config.stm32"
				if [ "1" = "1" ]; then
				    stm32wrapper4dbg -s "${buildDir}/$config$soc_suffix/$tfa_basename-$dt.stm32" -d "${buildDir}/$config$soc_suffix/debug-$tfa_basename-$dt-$config.stm32"
				fi
		    fi
		    # Specific for bl32 target
		    if [ "$(echo $tf_a_make_target | grep -cw 'bl32')" = "1" ]; then
				# Move 'bl32.elf' file to explicit file name with 'soc_suffix' info (same file for all devicetree build)
				# This avoid unexpected deployment for other config (cf. do_deploy task)
				if [ -f "${buildDir}/$config$soc_suffix/bl32/bl32.elf" ]; then
				    log_run mv -f "${buildDir}/$config$soc_suffix/bl32/bl32.elf" "${buildDir}/$config$soc_suffix/tf-a-bl32$soc_suffix.elf"
				fi
		    fi
		done
    done

    if [ "1" = "1" ]; then
		${srcDir}/tools/fwu_gen_metadata/fwumd_tool.py jsonparse "${srcDir}/plat/st/stm32mp1/default_metadata.json" -b "${buildDir}/metadata.bin"
    fi
}

do_buildstep_prepend

local_do_make_all

do_buildstep_append

