#!/bin/bash
# Generic buildstep script

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

require_script "stm32mp_common_utils.sh"

bootDir=${installDir}/boot
sysrootBootDir=${TARGET_SYSROOT_LOC}/boot

function local_do_install() {
	log_exec install -d ${bootDir}
    log_exec install -d ${bootDir}/arm-trusted-firmware

    unset i
    for config in  ${TF_A_CONFIG} ; do
        i=$(expr $i + 1)
        # Initialize devicetree list and tf-a basename
        dt_config=$(echo ${TF_A_DEVICETREE} | cut -d',' -f${i})
        tfa_basename=$(echo ${TF_A_BINARIES} | cut -d',' -f${i})
        tfa_file_type=$(echo ${TF_A_FILES} | cut -d',' -f${i})
        for dt in ${dt_config}; do
            # Init soc suffix
            soc_suffix=""
            if [ -n " ${stm32mp_soc_name} " ]; then
                for soc in  ${stm32mp_soc_name} ; do
                    [ "$(echo ${dt} | grep -c ${soc})" -eq 1 ] && soc_suffix="-${soc}"
                done
            fi
            for file_type in ${tfa_file_type}; do
                case "${file_type}" in
                bl2)
                    # Install TF-A binary
                    if [ -f "${buildDir}/${config}${soc_suffix}/${tfa_basename}-${dt}-${config}.stm32" ]; then
                        log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/${tfa_basename}-${dt}-${config}.stm32" "${bootDir}/arm-trusted-firmware/"
                        if [ "1" = "1" ]; then
                            log_exec install -d "${bootDir}/arm-trusted-firmware/debug"
                            log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/debug-${tfa_basename}-${dt}-${config}.stm32" "${bootDir}/arm-trusted-firmware/debug/"
                        fi
                    fi
                    if [ -n "1" ]; then
                        log_exec install -d ${bootDir}/arm-trusted-firmware/debug
                        if [ -f "${buildDir}/${config}${soc_suffix}/bl2/bl2.elf" ]; then
                            log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/bl2/bl2.elf" "${bootDir}/arm-trusted-firmware/debug/${tfa_basename}-bl2-${config}.elf"
                        fi
                    fi
                    ;;
                bl31)
                    # Install BL31 files
                    if [ -f "${buildDir}/${config}${soc_suffix}/bl31.bin" ]; then
                        log_exec install -d "${bootDir}/arm-trusted-firmware/bl31"
                        # Install BL31 binary
                        log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/bl31.bin" "${bootDir}/arm-trusted-firmware/bl31/${tfa_basename}-bl31${soc_suffix}.bin"
                        if [ -n "1" ]; then
                            if [ -f "${buildDir}/${config}${soc_suffix}/${tfa_basename}-bl31${soc_suffix}.elf" ]; then
                                log_exec install -d "${bootDir}/arm-trusted-firmware/bl32/debug"
                                log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/${tfa_basename}-bl31${soc_suffix}.elf" "${bootDir}/arm-trusted-firmware/bl31/debug/${tfa_basename}-bl31${soc_suffix}.elf"
                            fi
                        fi
                    fi
                    if [ -n "1" ]; then
                        log_exec install -d "${bootDir}/arm-trusted-firmware/debug"
                        if [ -f "${buildDir}/${config}${soc_suffix}/bl31/bl31.elf" ]; then
                            log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/bl31/bl31.elf" "${bootDir}/arm-trusted-firmware/debug/${tfa_basename}-bl31-${config}.elf"
                        fi
                    fi
                    ;;
                bl32)
                    # Install BL32 files
                    if [ -f "${buildDir}/${config}${soc_suffix}/bl32.bin" ]; then
                        log_exec install -d "${bootDir}/arm-trusted-firmware/bl32"
                        # Install BL32 binary
                        log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/bl32.bin" "${bootDir}/arm-trusted-firmware/bl32/${tfa_basename}-bl32${soc_suffix}.bin"
                        # Install BL32 devicetree
                        if [ -f "${buildDir}/${config}${soc_suffix}/fdts/${dt}-bl32.dtb" ]; then
                            log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/fdts/${dt}-bl32.dtb" "${bootDir}/arm-trusted-firmware/bl32/${dt}-bl32.dtb"
                        fi
                        if [ -n "1" ]; then
                            if [ -f "${buildDir}/${config}${soc_suffix}/${tfa_basename}-bl32${soc_suffix}.elf" ]; then
                                log_exec install -d "${bootDir}/arm-trusted-firmware/bl32/debug"
                                log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/${tfa_basename}-bl32${soc_suffix}.elf" "${bootDir}/arm-trusted-firmware/bl32/debug/${tfa_basename}-bl32${soc_suffix}.elf"
                            fi
                        fi
                    fi
                    if [ -n "1" ]; then
                        log_exec install -d "${bootDir}/arm-trusted-firmware/debug"
                        if [ -f "${buildDir}/${config}${soc_suffix}/bl32/bl32.elf" ]; then
                            log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/bl32/bl32.elf" "${bootDir}/arm-trusted-firmware/debug/${tfa_basename}-bl32-${config}.elf"
                        fi
                    fi
                    ;;
                fwconfig)
                    # Install fwconfig
                    if [ -f "${buildDir}/${config}${soc_suffix}/fdts/${dt}-fw-config.dtb" ]; then
                        log_exec install -d "${bootDir}/arm-trusted-firmware/fwconfig"
                        log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/fdts/${dt}-fw-config.dtb" "${bootDir}/arm-trusted-firmware/fwconfig/${dt}-fw-config-${config}.dtb"
                    fi
                    ;;
                esac
            done # for file_type in ${tfa_file_type}
        done # for dt in ${dt_config}
        if [ -n "1" ]; then
            log_exec install -d "${bootDir}/arm-trusted-firmware/debug"
            if [ -f "${buildDir}/${config}${soc_suffix}/bl1/bl1.elf" ]; then
                log_exec install -m 644 "${buildDir}/${config}${soc_suffix}/bl1/bl1.elf" "${bootDir}/arm-trusted-firmware/debug/${tfa_basename}-bl1-${config}.elf"
            fi
        fi
    done # for config in ${TF_A_CONFIG}

    if [ "1" = "1" ]; then
        log_exec install -d "${bootDir}/arm-trusted-firmware"
        if [ -f "${buildDir}/metadata.bin" ]; then
            log_exec install -m 644 "${buildDir}/metadata.bin" "${bootDir}/arm-trusted-firmware/${TF_A_METADATA_BIN}"
        fi
    fi
    install -d ${bootDir}
    install -d ${bootDir}/fip

    unset i
    for config in ${FIP_CONFIG}; do
        i=$(expr $i + 1)
        bl32_conf=$(echo ${FIP_BL32_CONF} | cut -d',' -f${i})
        dt_config=$(echo ${FIP_DEVICETREE} | cut -d',' -f${i})
        for dt in ${dt_config}; do
            # Init soc suffix
            soc_suffix=""
            if [ -n " ${stm32mp_soc_name} " ]; then
                for soc in  ${stm32mp_soc_name} ; do
                    [ "$(echo ${dt} | grep -c ${soc})" -eq 1 ] && soc_suffix="-${soc}"
                done
            fi
            # Init FIP fw-config settings
            [ -f "${bootDir}/arm-trusted-firmware/fwconfig/${dt}-fw-config-${config}.dtb" ] || fatal 1 "Missing ${dt}-fw-config-${config}.dtb file in folder: ${bootDir}/arm-trusted-firmware/fwconfig"
            FIP_FWCONFIG="--fw-config ${bootDir}/arm-trusted-firmware/fwconfig/${dt}-fw-config-${config}.dtb"
            # Init FIP hw-config settings
            [ -f "${SYSROOT_LOC}${datadir}/u-boot.dtb" ] || fatal 1 "Missing u-boot.dtb file in folder: ${SYSROOT_LOC}${datadir}"
            FIP_HWCONFIG="--hw-config ${SYSROOT_LOC}${datadir}/u-boot.dtb"
            # Init FIP nt-fw config
            [ -f "${SYSROOT_LOC}${datadir}/u-boot-nodtb.bin" ] || fatal 1 "Missing u-boot-nodtb.bin file in folder: ${SYSROOT_LOC}${datadir}"
            FIP_NTFW="--nt-fw ${SYSROOT_LOC}${datadir}/u-boot-nodtb.bin"
            # Init FIP bl31 settings
            if [ "${FIP_CONFIG_FW_TFA}" = "1" ]; then
                # Check for files
                [ -f "${bootDir}/arm-trusted-firmware/bl31/tf-a-bl31${soc_suffix}.bin" ] || fatal 1 "No tf-a-bl31${soc_suffix}.bin file in folder: ${bootDir}/arm-trusted-firmware/bl31"
                # Set FIP_BL31CONF
                FIP_BL31CONF="--soc-fw ${bootDir}/arm-trusted-firmware/bl31/tf-a-bl31${soc_suffix}.bin"
            else
                FIP_BL31CONF=""
            fi
            # Init FIP extra conf settings
            if [ "${bl32_conf}" = "tfa" ]; then
                # Check for files
                [ -f "${bootDir}/arm-trusted-firmware/bl32/tf-a-bl32${soc_suffix}.bin" ] || fatal 1 "No tf-a-bl32${soc_suffix}.bin file in folder: ${bootDir}/arm-trusted-firmware/bl32"
                [ -f "${bootDir}/arm-trusted-firmware/bl32/${dt}-bl32.dtb" ] || fatal 1 "No ${dt}-bl32.dtb file in folder: ${bootDir}/arm-trusted-firmware/bl32"
                # Set FIP_EXTRACONF
                FIP_EXTRACONF="\
                    --tos-fw ${bootDir}/arm-trusted-firmware/bl32/tf-a-bl32${soc_suffix}.bin \
                    --tos-fw-config ${bootDir}/arm-trusted-firmware/bl32/${dt}-bl32.dtb \
                    "
            elif [ "${bl32_conf}" = "optee" ]; then
                # Check for files
                [ -f "${sysrootBootDir}/tee-header_v2-${dt}.bin" ] || fatal 1 "Missing tee-header_v2-${dt}.bin file in folder: ${sysrootBootDir}"
                [ -f "${sysrootBootDir}/tee-pager_v2-${dt}.bin" ] || fatal 1 "Missing tee-pager_v2-${dt}.bin file in folder: ${sysrootBootDir}"
                [ -f "${sysrootBootDir}/tee-pageable_v2-${dt}.bin" ] || fatal 1 "Missing tee-pageable_v2-${dt}.bin file in folder: ${sysrootBootDir}"
                # Set FIP_EXTRACONF
                FIP_EXTRACONF="\
                    --tos-fw ${sysrootBootDir}/tee-header_v2-${dt}.bin \
                    --tos-fw-extra1 ${sysrootBootDir}/tee-pager_v2-${dt}.bin \
                    --tos-fw-extra2 ${sysrootBootDir}/tee-pageable_v2-${dt}.bin \
                    "
            else
                fatal 1 "Wrong configuration '${bl32_conf}' found in FIP_CONFIG for ${config} config."
            fi
            # Init certificate settings
            if [ "${FIP_SIGN_ENABLE}" = "1" ]; then
                soc_sign_suffix=""
                if [ -n " ${stm32mp_soc_name} " ]; then
                    unset k
                    for soc in  ${stm32mp_soc_name} ; do
                        k=$(expr $k + 1)
                        if [ "$(echo ${dt} | grep -c ${soc})" -eq 1 ]; then
                            sign_key=$(echo ${FIP_SIGN_KEY_PATH_SOC_LIST} | cut -d',' -f${k})
                        fi
                    done
                else
                    sign_key="${FIP_SIGN_KEY_PATH}"
                fi
                if [ -z "${sign_key}" ]; then
                    fatal 1 "Please make sure to configure \"FIP_SIGN_KEY\" var to signing key file."
                fi
                FIP_CERTCONF="\
                    --tb-fw-cert ${workDir}/tb_fw.crt \
                    --trusted-key-cert ${workDir}/trusted_key.crt \
                    --nt-fw-cert ${workDir}/nt_fw_content.crt \
                    --nt-fw-key-cert ${workDir}/nt_fw_key.crt \
                    --tos-fw-cert ${workDir}/tos_fw_content.crt \
                    --tos-fw-key-cert ${workDir}/tos_fw_key.crt \
                    --stm32mp-cfg-cert ${workDir}/stm32mp_cfg_cert.crt \
                    "
                # Need fake bl2 binary to generate certificates
                touch ${workDir}/bl2-fake.bin
                # Generate certificates
                log_exec cert_create -n --tfw-nvctr 0 --ntfw-nvctr 0 --key-alg ecdsa --hash-alg sha256 \
			                        --rot-key ${sign_key} \
			                        --rot-key-pwd  \
			                        ${FIP_FWCONFIG} \
			                        ${FIP_HWCONFIG} \
			                        ${FIP_NTFW} \
			                        ${FIP_EXTRACONF} \
			                        ${FIP_CERTCONF} \
			                        --tb-fw ${workDir}/bl2-fake.bin
                # Remove fake bl2 binary
                log_exec rm -f ${workDir}/bl2-fake.bin
            else
                FIP_CERTCONF=""
            fi
            # Generate FIP binary
            log "fiptool create \
		                ${FIP_FWCONFIG} \
		                ${FIP_HWCONFIG} \
		                ${FIP_NTFW} \
		                ${FIP_BL31CONF} \
		                ${FIP_EXTRACONF} \
		                ${FIP_CERTCONF} \
		                ${bootDir}/fip/fip-${dt}-${config}.bin"
            log_exec fiptool create \
			            ${FIP_FWCONFIG} \
			            ${FIP_HWCONFIG} \
			            ${FIP_NTFW} \
			            ${FIP_BL31CONF} \
			            ${FIP_EXTRACONF} \
			            ${FIP_CERTCONF} \
			            ${bootDir}/fip/fip-${dt}-${config}.bin
        done
    done
}

do_buildstep_prepend

local_do_install

do_buildstep_append
