#!/bin/bash
#
# Recipe-specific step for task Install: task.install.u-boot-stm32mp_v2021.10-stm32mp-r2-r0 (make_install.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

require_script "stm32mp_common_utils.sh"

bbwarn() {
	if [ -p ${workDir}/temp/fifo.20119 ] ; then
		printf "%b\0" "bbwarn $*" > ${workDir}/temp/fifo.20119
	else
		echo "WARNING: $*"
	fi
}

install_helper() {
	if [ -f "u-boot.dtb" ]; then
		# UBOOT_DTB_BINARY is a symlink to UBOOT_DTB_IMAGE, so we
		# need both of them.
		log_run install -Dm 0644 u-boot.dtb ${installDir}${datadir}/u-boot-${stm32_machine}-v2021.10-stm32mp-r2-r0.dtb
		log_run ln -sf u-boot-${stm32_machine}-v2021.10-stm32mp-r2-r0.dtb ${installDir}${datadir}/u-boot.dtb
	else
		bbwarn "u-boot.dtb not found"
	fi
}

install_spl_helper() {
	if [ -f "u-boot-spl.dtb" ]; then
		log_run install -Dm 0644 ${buildDir}/$config/spl/u-boot-spl.dtb ${installDir}${datadir}/u-boot-spl-${stm32_machine}-v2021.10-stm32mp-r2-r0.dtb
		log_run ln -sf u-boot-spl-${stm32_machine}-v2021.10-stm32mp-r2-r0.dtb ${installDir}${datadir}/u-boot-spl.dtb
	else
		bbwarn "u-boot-spl.dtb not found"
	fi
	if [ -f "u-boot-nodtb.bin" ] ; then
		log_run install -Dm 0644 ${buildDir}/$config/u-boot-nodtb.bin ${installDir}${datadir}/u-boot-nodtb-${stm32_machine}-v2021.10-stm32mp-r2-r0.bin
		log_run ln -sf u-boot-nodtb-${stm32_machine}-v2021.10-stm32mp-r2-r0.bin ${installDir}${datadir}/u-boot-nodtb.bin
	else
		bbwarn "u-boot-nodtb.bin not found"
	fi

	# We need to install a 'stub' u-boot-fitimage + its to datadir,
	# so that the KERNEL_PN can use the correct filename when
	# assembling and deploying them
	touch ${installDir}/${datadir}/u-boot-fitImage-${stm32_machine}-v2021.10-stm32mp-r2-r0
	touch ${installDir}/${datadir}/u-boot-its-${stm32_machine}-v2021.10-stm32mp-r2-r0
}


function local_do_make_install() {
    if [ -n " ${UBOOT_CONFIG} " ]
    then
		for config in  ${UBOOT_MACHINE}; do
		    i=$(expr $i + 1);
		    for type in  ${UBOOT_CONFIG} ; do
			j=$(expr $j + 1);
			if [ $j -eq $i ]
			then
			    log_run install -D -m 644 ${buildDir}/$config/u-boot-$type.bin ${installDir}/boot/u-boot-$type-v2021.10-stm32mp-r2-r0.bin
			    log_run ln -sf u-boot-$type-v2021.10-stm32mp-r2-r0.bin ${installDir}/boot/u-boot.bin-$type
			    log_run ln -sf u-boot-$type-v2021.10-stm32mp-r2-r0.bin ${installDir}/boot/u-boot.bin
	
			    # Install the uboot-initial-env
			    if [ -n "u-boot-stm32mp-initial-env" ]; then
				log_run install -D -m 644 ${buildDir}/$config/u-boot-initial-env-$type ${installDir}/${sysconfdir}/u-boot-stm32mp-initial-env-${stm32_machine}-$type-v2021.10-stm32mp-r2-r0
				log_run ln -sf u-boot-stm32mp-initial-env-${stm32_machine}-$type-v2021.10-stm32mp-r2-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp-initial-env-${stm32_machine}-$type
				log_run ln -sf u-boot-stm32mp-initial-env-${stm32_machine}-$type-v2021.10-stm32mp-r2-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp-initial-env-$type
				log_run ln -sf u-boot-stm32mp-initial-env-${stm32_machine}-$type-v2021.10-stm32mp-r2-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp-initial-env
			    fi
			fi
		    done
		    unset j
		done
		unset i
    else
		log_run install -D -m 644 ${buildDir}/u-boot.bin ${installDir}/boot/u-boot-${stm32_machine}-v2021.10-stm32mp-r2-r0.bin
		log_run ln -sf u-boot-${stm32_machine}-v2021.10-stm32mp-r2-r0.bin ${installDir}/boot/u-boot.bin
	
		# Install the uboot-initial-env
		if [ -n "u-boot-stm32mp-initial-env" ]; then
		    log_run install -D -m 644 ${buildDir}/u-boot-initial-env ${installDir}/${sysconfdir}/u-boot-stm32mp-initial-env-${stm32_machine}-v2021.10-stm32mp-r2-r0
		    log_run ln -sf u-boot-stm32mp-initial-env-${stm32_machine}-v2021.10-stm32mp-r2-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp-initial-env-${stm32_machine}
		    log_run ln -sf u-boot-stm32mp-initial-env-${stm32_machine}-v2021.10-stm32mp-r2-r0 ${installDir}/${sysconfdir}/u-boot-stm32mp-initial-env
		fi
    fi

    if [ -n "u-boot" ]
    then
		if [ -n " ${UBOOT_CONFIG} " ]
		then
		    for config in  ${UBOOT_MACHINE}; do
			i=$(expr $i + 1);
			for type in  ${UBOOT_CONFIG} ; do
			    j=$(expr $j + 1);
			    if [ $j -eq $i ]
			    then
				log_run install -m 644 ${buildDir}/$config/u-boot ${installDir}/boot/u-boot-$type-v2021.10-stm32mp-r2-r0.elf
				log_run ln -sf u-boot-$type-v2021.10-stm32mp-r2-r0.elf ${installDir}/boot/u-boot.bin-$type
				log_run ln -sf u-boot-$type-v2021.10-stm32mp-r2-r0.elf ${installDir}/boot/u-boot.bin
			    fi
			done
			unset j
		    done
		    unset i
		else
		    log_run install -m 644 ${buildDir}/u-boot ${installDir}/boot/u-boot-${stm32_machine}-v2021.10-stm32mp-r2-r0.elf
		    log_run ln -sf u-boot-${stm32_machine}-v2021.10-stm32mp-r2-r0.elf ${installDir}/boot/u-boot.elf
		fi
    fi

    if [ -e ${workDir}/fw_env.config ] ; then
		log_run install -d ${installDir}${sysconfdir}
		log_run install -m 644 ${workDir}/fw_env.config ${installDir}${sysconfdir}/fw_env.config
    fi

    if [ -n "" ]
    then
		if [ -n " ${UBOOT_CONFIG} " ]
		then
		    for config in  ${UBOOT_MACHINE}; do
				i=$(expr $i + 1);
				for type in  ${UBOOT_CONFIG} ; do
				    j=$(expr $j + 1);
				    if [ $j -eq $i ]
				    then
					 log_run install -m 644 ${buildDir}/$config ${installDir}/boot/u-boot-spl.stm32-$type-v2021.10-stm32mp-r2-r0
					 log_run ln -sf u-boot-spl.stm32-$type-v2021.10-stm32mp-r2-r0 ${installDir}/boot/-$type
					 log_run ln -sf u-boot-spl.stm32-$type-v2021.10-stm32mp-r2-r0 ${installDir}/boot
				    fi
				done
				unset j
		    done
		    unset i
		else
		    log_run install -m 644 ${buildDir} ${installDir}/boot/u-boot-spl.stm32-${stm32_machine}-v2021.10-stm32mp-r2-r0
		    log_run ln -sf u-boot-spl.stm32-${stm32_machine}-v2021.10-stm32mp-r2-r0 ${installDir}/boot
		fi
    fi

    if [ -n "$UBOOT_ENV" ]
    then
		log_run install -m 644 ${workDir}/.txt ${installDir}/boot/u-boot-env-${stm32_machine}-v2021.10-stm32mp-r2-r0.txt
		log_run ln -sf u-boot-env-${stm32_machine}-v2021.10-stm32mp-r2-r0.txt ${installDir}/boot/.txt
    fi

    if [ "$UBOOT_EXTLINUX" = "1" ]
    then
		log_run install -Dm 0644 ${buildDir}/extlinux.conf ${installDir}//boot/extlinux/extlinux.conf
    fi
    
	if [ "${recipe_name}" = "${recipe_name}" ]; then
		if [ -n " ${UBOOT_CONFIG} " ]; then
			for config in  ${UBOOT_MACHINE}; do
				cd ${buildDir}/$config
				install_helper
				install_spl_helper
			done
		else
			cd ${buildDir}
			install_helper
			install_spl_helper
		fi
	fi
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append

