#!/bin/bash
#
# Recipe-specific step for task Install: task.install.weston-init_1.0-r0 (make_install.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

function local_do_make_install() {
	if [ "systemd" != "systemd" ]; then
		log_run install -Dm755 ${buildDir}/init ${installDir}/${sysconfdir}/init.d/weston
		sed -i 's#ROOTHOME#/home/root#' ${installDir}/${sysconfdir}/init.d/weston
	fi
	log_run install -D -p -m0644 ${buildDir}/weston.ini ${installDir}${sysconfdir}/xdg/weston/weston.ini
	log_run install -Dm644 ${buildDir}/weston.env ${installDir}${sysconfdir}/default/weston

	# Install Weston systemd service and accompanying udev rule
	log_run install -D -p -m0644 ${buildDir}/weston.service ${installDir}${base_libdir}/systemd/system/weston.service
	log_run install -D -p -m0644 ${buildDir}/weston.socket ${installDir}${base_libdir}/systemd/system/weston.socket
	if [ "pam" ]; then
		log_run install -D -p -m0644 ${buildDir}/weston-autologin ${installDir}${sysconfdir}/pam.d/weston-autologin
	fi
	sed -i -e s:${sysconfdir}:${sysconfdir}:g \
		-e s:${bindir}:${bindir}:g \
		-e s:${localstatedir}:${localstatedir}:g \
		${installDir}${base_libdir}/systemd/system/weston.service
	# Install weston-start script
	log_run install -Dm755 ${buildDir}/weston-start ${installDir}${bindir}/weston-start
	sed -i 's,@DATADIR@,'"${datadir}"',g' ${installDir}${bindir}/weston-start
	sed -i 's,@LOCALSTATEDIR@,'"${localstatedir}"',g' ${installDir}${bindir}/weston-start
	if [ -n "" ]; then
		sed -i -e "/^\[core\]/a backend=-backend.so" ${installDir}${sysconfdir}/xdg/weston/weston.ini
	fi

	if [ "no" = "yes" ]; then
		sed -i -e "/^\[core\]/a idle-time=0" ${installDir}${sysconfdir}/xdg/weston/weston.ini
	fi

	if [ "no" = "yes" ]; then
		sed -i -e "/^\[core\]/a use-pixman=true" ${installDir}${sysconfdir}/xdg/weston/weston.ini
	fi

	log_run install -dm 755 ${installDir}/home/weston
    log_run install -d ${installDir}${sysconfdir}/xdg/weston
    log_run install -d ${installDir}${datadir}/weston/backgrounds
    log_run install -d ${installDir}${datadir}/weston/icon

    log_run install -m 0644 ${buildDir}/weston.ini ${installDir}${sysconfdir}/xdg/weston

    log_run install -m 0644 ${buildDir}/utilities-terminal.png ${installDir}${datadir}/weston/icon/utilities-terminal.png
    log_run install -m 0644 ${buildDir}/ac6_SW4Linux_wallpaper_1366x768.png ${installDir}${datadir}/weston/backgrounds/ac6_SW4Linux_wallpaper_1366x768.png

    log_run install -m 0644 ${buildDir}/space.png ${installDir}${datadir}/weston/icon

    log_run install -d ${installDir}${base_libdir}/systemd/system ${installDir}${sbindir}

    log_run install -d ${installDir}${base_libdir}/systemd/system
    if [ -e ${installDir}${base_libdir}/systemd/system/weston.service ]; then
        rm ${installDir}${base_libdir}/systemd/system/weston.service ${installDir}${base_libdir}/systemd/system/weston.socket
        log_run install -D -p -m0644 ${buildDir}/weston-launch.service ${installDir}${base_libdir}/systemd/system/weston-launch.service
        sed -i -e s:${sysconfdir}:${sysconfdir}:g \
            -e s:${bindir}:${bindir}:g \
            -e s:${localstatedir}:${localstatedir}:g \
            ${installDir}${base_libdir}/systemd/system/weston-launch.service
        log_run install -d ${installDir}${sysconfdir}/systemd/system/multi-user.target.wants
        #log_run ln -s ${base_libdir}/systemd/system/weston-launch.service ${installDir}${sysconfdir}/systemd/system/multi-user.target.wants/display-manager.service
        log_run install -D -p -m0644 ${buildDir}/weston-checkgpu.service ${installDir}${base_libdir}/systemd/system
    fi

    log_run install -d ${installDir}${sysconfdir}/profile.d
    log_run install -m 0755 ${buildDir}/weston_profile.sh ${installDir}${sysconfdir}/profile.d

    if false; then
        # uncomment modules line for support of xwayland
        sed -i -e 's,#xwayland=true,xwayland=true,g' ${installDir}${sysconfdir}/xdg/weston/weston.ini
    fi
    sed -i 's,@DATADIR@,'"${datadir}"',g' ${installDir}${bindir}/weston-start

    # check GPU
    log_run install -d ${installDir}/home/root
    log_run install -m 644 ${buildDir}/README-CHECK-GPU ${installDir}/home/root
    if ! test -f ${installDir}${base_sbindir}/check-gpu; then
        log_run install -d ${installDir}${base_sbindir}
        echo '#!'"${base_bindir}"'/sh' > ${buildDir}/check-gpu.empty
        echo "${base_bindir}"'/true' >> ${buildDir}/check-gpu.empty
        log_run install -m 755 ${buildDir}/check-gpu.empty ${installDir}${base_sbindir}/check-gpu
    fi

    # udev rules for galcore
    log_run install -D -p -m0644 ${buildDir}/72-galcore.rules ${installDir}${sysconfdir}/udev/rules.d/72-galcore.rules

    # AUDIO: swith between analog stero and HDMI
    log_run install -d ${installDir}${sysconfdir}/default
    log_run install -m 0644 ${buildDir}/default_pulseaudio_profile ${installDir}${sysconfdir}/default/pulseaudio_profile
    log_run install -d ${installDir}${sysconfdir}/udev/rules.d
    log_run install -p -m 0644 ${buildDir}/73-pulseaudio-hdmi.rules ${installDir}${sysconfdir}/udev/rules.d/73-pulseaudio-hdmi.rules
    log_run install -d ${installDir}${bindir}
    log_run install -m 0755 ${buildDir}/pulseaudio_hdmi_switch.sh ${installDir}${bindir}
    if true; then
        log_run install -d ${installDir}${base_sbindir}
        log_run install -m 755 ${buildDir}/check-gpu ${installDir}${base_sbindir}
    fi
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append
